@@ -919,7 +919,7 @@ ags_effect_line_add_ladspa_effect(AgsEffectLine *effect_line,
   GList *play_port, *recall_port;
   GList *start_plugin_port, *plugin_port;
   
-  gdouble step;
+  gdouble page, step;
   guint port_count;
 
   guint x, y;
@@ -1266,8 +1266,22 @@ ags_effect_line_add_ladspa_effect(AgsEffectLine *effect_line,
 	  step = (upper - lower) / step_count;
 	}
 
+	if(step_count > 8){
+	  if(upper >= 0.0 && lower >= 0.0){
+	    page = (upper - lower) / AGS_DIAL_DEFAULT_PRECISION;
+	  }else if(upper < 0.0 && lower < 0.0){
+	    page = -1.0 * (lower - upper) / AGS_DIAL_DEFAULT_PRECISION;
+	  }else{
+	    page = (upper - lower) / AGS_DIAL_DEFAULT_PRECISION;
+	  }
+	}else{
+	  page = step;
+	}
+	
 	gtk_adjustment_set_step_increment(adjustment,
 					  step);
+	gtk_adjustment_set_page_increment(adjustment,
+					  page);
 	gtk_adjustment_set_lower(adjustment,
 				 lower);
 	gtk_adjustment_set_upper(adjustment,
@@ -1342,8 +1356,22 @@ ags_effect_line_add_ladspa_effect(AgsEffectLine *effect_line,
 	  step = (upper - lower) / step_count;
 	}
 
+	if(step_count > 8){
+	  if(upper >= 0.0 && lower >= 0.0){
+	    page = (upper - lower) / AGS_DIAL_DEFAULT_PRECISION;
+	  }else if(upper < 0.0 && lower < 0.0){
+	    page = -1.0 * (lower - upper) / AGS_DIAL_DEFAULT_PRECISION;
+	  }else{
+	    page = (upper - lower) / AGS_DIAL_DEFAULT_PRECISION;
+	  }
+	}else{
+	  page = step;
+	}
+	
 	gtk_adjustment_set_step_increment(adjustment,
 					  step);
+	gtk_adjustment_set_page_increment(adjustment,
+					  page);
 	gtk_adjustment_set_lower(adjustment,
 				 lower);
 	gtk_adjustment_set_upper(adjustment,
@@ -1418,8 +1446,22 @@ ags_effect_line_add_ladspa_effect(AgsEffectLine *effect_line,
 	  step = (upper - lower) / step_count;
 	}
 
+	if(step_count > 8){
+	  if(upper >= 0.0 && lower >= 0.0){
+	    page = (upper - lower) / AGS_DIAL_DEFAULT_PRECISION;
+	  }else if(upper < 0.0 && lower < 0.0){
+	    page = -1.0 * (lower - upper) / AGS_DIAL_DEFAULT_PRECISION;
+	  }else{
+	    page = (upper - lower) / AGS_DIAL_DEFAULT_PRECISION;
+	  }
+	}else{
+	  page = step;
+	}
+	
 	gtk_adjustment_set_step_increment(adjustment,
 					  step);
+	gtk_adjustment_set_page_increment(adjustment,
+					  page);
 	gtk_adjustment_set_lower(adjustment,
 				 lower);
 	gtk_adjustment_set_upper(adjustment,
@@ -1510,7 +1552,7 @@ ags_effect_line_add_lv2_effect(AgsEffectLine *effect_line,
 
   gchar *uri;
   
-  gdouble step;
+  gdouble page, step;
   guint port_count;
 
   guint x, y;
@@ -1827,8 +1869,22 @@ ags_effect_line_add_lv2_effect(AgsEffectLine *effect_line,
 	  step = (upper - lower) / step_count;
 	}
 
+	if(step_count > 8){
+	  if(upper >= 0.0 && lower >= 0.0){
+	    page = (upper - lower) / AGS_DIAL_DEFAULT_PRECISION;
+	  }else if(upper < 0.0 && lower < 0.0){
+	    page = -1.0 * (lower - upper) / AGS_DIAL_DEFAULT_PRECISION;
+	  }else{
+	    page = (upper - lower) / AGS_DIAL_DEFAULT_PRECISION;
+	  }
+	}else{
+	  page = step;
+	}
+	
 	gtk_adjustment_set_step_increment(adjustment,
 					  step);
+	gtk_adjustment_set_page_increment(adjustment,
+					  page);
 	gtk_adjustment_set_lower(adjustment,
 				 lower);
 	gtk_adjustment_set_upper(adjustment,
@@ -1903,8 +1959,22 @@ ags_effect_line_add_lv2_effect(AgsEffectLine *effect_line,
 	  step = (upper - lower) / step_count;
 	}
 
+	if(step_count > 8){
+	  if(upper >= 0.0 && lower >= 0.0){
+	    page = (upper - lower) / AGS_DIAL_DEFAULT_PRECISION;
+	  }else if(upper < 0.0 && lower < 0.0){
+	    page = -1.0 * (lower - upper) / AGS_DIAL_DEFAULT_PRECISION;
+	  }else{
+	    page = (upper - lower) / AGS_DIAL_DEFAULT_PRECISION;
+	  }
+	}else{
+	  page = step;
+	}
+	
 	gtk_adjustment_set_step_increment(adjustment,
 					  step);
+	gtk_adjustment_set_page_increment(adjustment,
+					  page);
 	gtk_adjustment_set_lower(adjustment,
 				 lower);
 	gtk_adjustment_set_upper(adjustment,
@@ -1979,8 +2049,22 @@ ags_effect_line_add_lv2_effect(AgsEffectLine *effect_line,
 	  step = (upper - lower) / step_count;
 	}
 
+	if(step_count > 8){
+	  if(upper >= 0.0 && lower >= 0.0){
+	    page = (upper - lower) / AGS_DIAL_DEFAULT_PRECISION;
+	  }else if(upper < 0.0 && lower < 0.0){
+	    page = -1.0 * (lower - upper) / AGS_DIAL_DEFAULT_PRECISION;
+	  }else{
+	    page = (upper - lower) / AGS_DIAL_DEFAULT_PRECISION;
+	  }
+	}else{
+	  page = step;
+	}
+	
 	gtk_adjustment_set_step_increment(adjustment,
 					  step);
+	gtk_adjustment_set_page_increment(adjustment,
+					  page);
 	gtk_adjustment_set_lower(adjustment,
 				 lower);
 	gtk_adjustment_set_upper(adjustment,
